==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QOffscreenSurface_shell.h <==
#ifndef QOFFSCREENSURFACE_SHELL_H
#define QOFFSCREENSURFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qoffscreensurface.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>


class QOffscreenSurface_shell : public QOffscreenSurface, public QtJambiShellInterface
{
public:
    QOffscreenSurface_shell(QScreen* screen0 = nullptr, QObject* parent1 = nullptr);
    ~QOffscreenSurface_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QSurfaceFormat format() const override;
    QSize size() const override;
    QSurface::SurfaceType surfaceType() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOffscreenSurface_access : public QOffscreenSurface
{
    jobject __qt_nativeInterface_const_char_ptr_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jclass name0) const;
    jobject __qt_format(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_size(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_surfaceType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QOFFSCREENSURFACE_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QOffscreenSurface_shell.h <==
#ifndef QOFFSCREENSURFACE_SHELL_H
#define QOFFSCREENSURFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qoffscreensurface.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>


class QOffscreenSurface_shell : public QOffscreenSurface, public QtJambiShellInterface
{
public:
    QOffscreenSurface_shell(QScreen* screen0 = nullptr, QObject* parent1 = nullptr);
    ~QOffscreenSurface_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QSurfaceFormat format() const override;
    QSize size() const override;
    QSurface::SurfaceType surfaceType() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOffscreenSurface_access : public QOffscreenSurface
{
    jobject __qt_nativeInterface_const_char_ptr_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jclass name0) const;
    jobject __qt_format_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_size_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_surfaceType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QOFFSCREENSURFACE_SHELL_H
